#####################################################################################
#										    #
#  	multipoppuffins.R: R script to run WinBUGS program for             	    #
#	modelling survival at multi-population scales using mark-recapture data,    #
#							                            #
#####################################################################################
#	                                                			    #
#	Authors: Olivier Gimenez (*) (December 2008)                         	    #
#                                                                                   #
#		* Centre d'Ecologie Fonctionnelle et Evolutive - CNRS               #
#		  1919 Route de Mende						    #
#		  34293 Montpellier Cedex 5 - France	                            #
#										    #
#		  email: olivier.gimenez@cefe.cnrs.fr				    #
#                                                                                   #
#####################################################################################
#										    #
#       This program is meant to be used for non-commercial purposes only. Please   #
#       report any problems/ suggestions to Olivier Gimenez at:                     #
#	                                                                            #
#		olivier.gimenez@cefe.cnrs.fr        				    #
#	                                                                            #
#                                                                                   #
#	See the WinBUGS manual for detailed instructions on model specification     #
#	and updating. WinBUGS software and manuals can be obtained at:              #
#               http://www.mrc-bsu.cam.ac.uk/bugs/	                            #
#                                                                                   #
#####################################################################################

#####################################################################################
# model with sea surface temperature (SST) as a covariate
# and both global- and local-scale variances
#####################################################################################


# specify working directory, needs to be adapted for your own purpose
setwd("C:/OG/RECHERCHE/PAPIERS/EN COURS/SOUMIS/vlad SPATIAL CMR/redaction/resoumission Ecology/codes")

# load required package
library("R2WinBUGS")

N=4 # number of populations
I=12 # number of capture occasions
J=11 # number of recapture occasions

# read in sea surface temperature covariate, and standardization
SST <- matrix(scan("SST(Y-1).dat"),nrow=I,byrow=T)
moyenne <- apply(SST,2,mean)
ecarttype <- apply(SST,2,sd)
SST <- cbind((SST[,1]-moyenne[1])/ecarttype[1],(SST[,2]-moyenne[2])/ecarttype[2],(SST[,3]-moyenne[3])/ecarttype[3],(SST[,4]-moyenne[4])/ecarttype[4])
covariate = SST

# read in m-array for the four populations
# note: uses a 2-age class structure to incorporate a trap-dependence effect

# Skommer colony
m1J <- matrix(scan("marrayp1_Skomer.dat"),I,I+1,byrow=T)
msite1J <- cbind(m1J[,2:(I+1)],m1J[,1]-apply(m1J[,1:I+1],1,sum))

m1A <- matrix(scan("marrayp2_Skomer.dat"),J,J+1,byrow=T)
msite1A <- cbind(m1A[,2:(J+1)],m1A[,1]-apply(m1A[,1:J+1],1,sum))

# Isle of May colony
m2J <- matrix(scan("marrayp1_May.dat"),I,I+1,byrow=T)
msite2J <- cbind(m2J[,2:(I+1)],m2J[,1]-apply(m2J[,1:I+1],1,sum))

m2A <- matrix(scan("marrayp2_May.dat"),J,J+1,byrow=T)
msite2A <- cbind(m2A[,2:(J+1)],m2A[,1]-apply(m2A[,1:J+1],1,sum))

# Fair isle colony
m3J <- matrix(scan("marrayp1_Fair.dat"),I,I+1,byrow=T)
msite3J <- cbind(m3J[,2:(I+1)],m3J[,1]-apply(m3J[,1:I+1],1,sum))

m3A <- matrix(scan("marrayp2_Fair.dat"),J,J+1,byrow=T)
msite3A <- cbind(m3A[,2:(J+1)],m3A[,1]-apply(m3A[,1:J+1],1,sum))

# Rost colony
m4J <- matrix(scan("marrayp1_Rost.dat"),I,I+1,byrow=T)
msite4J <- cbind(m4J[,2:(I+1)],m4J[,1]-apply(m4J[,1:I+1],1,sum))

m4A <- matrix(scan("marrayp2_Rost.dat"),J,J+1,byrow=T)
msite4A <- cbind(m4A[,2:(J+1)],m4A[,1]-apply(m4A[,1:J+1],1,sum))

msiteJ <- array(dim = c(I,I+1,4))
msiteJ[,,1] <- msite1J
msiteJ[,,2] <- msite2J
msiteJ[,,3] <- msite3J
msiteJ[,,4] <- msite4J
msiteJ <- aperm(msiteJ, c(1,3,2)) 

msiteA <- array(dim = c(J,J+1,4))
msiteA[,,1] <- msite1A
msiteA[,,2] <- msite2A
msiteA[,,3] <- msite3A
msiteA[,,4] <- msite4A
msiteA <- aperm(msiteA, c(1,3,2)) 

# number of individuals never seen again 
rJ <- matrix(0,nrow=I,ncol=N)
for (i in 1:I) {
for (s in 1:N) {
rJ[i,s] <- sum(msiteJ[i,s,1:I])
}}

rA <- matrix(0,nrow=J,ncol=N)
for (i in 1:J) {
for (s in 1:N) {
rA[i,s] <- sum(msiteA[i,s,1:J])
}}


# Define the design matrices - linear effect of SST on the four populations, 
# but Fair isle for which we specify a quadratic effect
X1 <- cbind(rep(1,length(covariate[,1])),covariate[,1])
X2 <- cbind(rep(1,length(covariate[,2])),covariate[,2],covariate[,2]*covariate[,2])
X3 <- cbind(rep(1,length(covariate[,3])),covariate[,3])
X4 <- cbind(rep(1,length(covariate[,4])),covariate[,4])

# data
dataz <- list("msiteJ","msiteA","N","I","J","rJ","rA","X1","X2","X3","X4")

# initial values

p10 <- matrix(0,nrow=I,ncol=N)
for (i in 1:I){
for (s in 1:N){
p10[i,s] <- runif(1,0.5,1)
}
}

p20 <- matrix(0,nrow=J,ncol=N)
for (i in 1:J){
for (s in 1:N){
p20[i,s] <- runif(1,0.5,1)
}
}

init1 <- list (p1=p10, p2=p20,beta1=rep(0,2),beta2=rep(0,3),beta3=rep(0,2),beta4=rep(0,2),tau.delta=0.01,tau.epsilon=0.01)
init2 <- list (p1=p10, p2=p20,beta1=rep(0,2),beta2=rep(0,3),beta3=rep(0,2),beta4=rep(0,2),tau.delta=0.01,tau.epsilon=0.01)

# parameters to be monitored
parameters <- c("p1","p2","survival","beta1","beta2","beta3","beta4","m1","m2","m3","m4","vardelta","varepsilon","ICC")

# run WinBUGS
paramqgeostat.sim <- bugs(dataz, list(init1,init2), parameters, "multipoppuffins.bug", n.chains=2, n.iter=150, n.burnin = 100)

# display results
round(paramqgeostat.sim$summary,2)



